@@ -1,7 +1,7 @@
 package PERLANCAR::Tree::Examples;
 
-our $DATE = '2016-04-02'; # DATE
-our $VERSION = '1.000.003'; # VERSION
+our $DATE = '2016-04-03'; # DATE
+our $VERSION = '1.000.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -14,7 +14,7 @@ use Exporter::Rinci qw(import);
 
 our %SPEC;
 
-$SPEC{gen_sample_tree} = {
+$SPEC{gen_sample_data} = {
     v => 1.1,
     summary => 'Generate sample tree object',
     args => {
@@ -38,10 +38,12 @@ node.
 _
             req => 1,
             pos => 0,
+            tags => ['data-parameter'],
         },
         backend => {
             schema => ['str*', in=>['array', 'hash']],
             default => 'hash',
+            tags => ['data-parameter'],
         },
     },
     result => {
@@ -49,7 +51,7 @@ _
     },
     result_naked => 1,
 };
-sub gen_sample_tree {
+sub gen_sample_data {
     my %args = @_;
 
     my $size = $args{size} or die "Please specify size";
@@ -90,6 +92,9 @@ sub gen_sample_tree {
     );
 }
 
+# old name, for backward compatibility
+*gen_sample_tree = \&gen_sample_data;
+
 package # hide from PAUSE
     Tree::Example::HashNode;
 use parent qw(Tree::Object::Hash);
@@ -173,7 +178,7 @@ PERLANCAR::Tree::Examples - Generate sample tree object
 
 =head1 VERSION
 
-This document describes version 1.000.003 of PERLANCAR::Tree::Examples (from Perl distribution PERLANCAR-Tree-Examples), released on 2016-04-02.
+This document describes version 1.000.004 of PERLANCAR::Tree::Examples (from Perl distribution PERLANCAR-Tree-Examples), released on 2016-04-03.
 
 =head1 SYNOPSIS
 
@@ -284,7 +289,7 @@ these example trees for benchmarking or testing in several other distributions.
 =head1 FUNCTIONS
 
 
-=head2 gen_sample_tree(%args) -> obj
+=head2 gen_sample_data(%args) -> obj
 
 Generate sample tree object.
 
@@ -316,6 +321,8 @@ C<Org::Document> tree generated when parsing my C<todo.org> document circa early
 
 Return value:  (obj)
 
+=for Pod::Coverage ^(gen_sample_tree)$
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/PERLANCAR-Tree-Examples>.
